@@ -1,11 +1,12 @@
-/* body.c - This part shared by the test programs (except for the randomisation
+/* body.c - This part is shared by the test programs (except for the randomisation
  *          tests)
  *
- * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
+ * Copyright (c)2003,2004 by Peter Busser <peter@adamantix.org>
  * This file has been released under the GNU Public Licence version 2 or later
  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <sys/mman.h>
 #include <unistd.h>
 #include <errno.h>
@@ -13,6 +14,7 @@
 #include <signal.h>
 #include <sys/types.h>
 #include <sys/wait.h>
+#include <pthread.h>
 
 #ifndef PAGESIZE
 #define PAGESIZE	(4096)
@@ -21,16 +23,51 @@
 extern int doit( void );
 extern char *testname;
 
+static void *test_thread(void *p)
+{
+	pause();
+	return NULL;
+}
+
 int main( int argc, char *argv[] )
 {
 	int status;
+	char *mode;
+	/* This defaults to 1 as a safety mechanism. It is better to fail in
+	 * blackhat mode, because kiddie mode can produce overly optimistic
+	 * results.
+	 */
+	int paxtest_mode = 1;
+
+	/* Dummy nested function */
+	void dummy(void) {}
+
+	mode = getenv( "PAXTEST_MODE" );
+	if( mode == NULL ) {
+		paxtest_mode = 1;
+	} else {
+		if( strcmp(mode,"0") == 0 ) {
+			paxtest_mode = 0;
+		} else if( strcmp(mode,"1") == 0 ) {
+			paxtest_mode = 1;
+		}
+	}
 
 	printf( "%s: ", testname );
 	fflush( stdout );
 
 	if( fork() == 0 ) {
-		do_mprotect((unsigned long)argv & ~4095U, 4096, PROT_READ|PROT_WRITE|PROT_EXEC);
-		doit();
+		/* Perform a dirty (but not unrealistic) trick to circumvent
+		 * the kernel protection.
+		 */
+		if( paxtest_mode == 1 ) {
+			pthread_t thread;
+			pthread_create(&thread, NULL, test_thread, dummy);
+			doit();
+			pthread_kill(thread, SIGTERM);
+		} else {
+			doit();
+		}
 	} else {
 		wait( &status );
 		if( WIFEXITED(status) == 0 ) {
