@@ -1,6 +1,6 @@
 /* rettofunc1.c - Tests wether return to function exploits work or not.
  *
- * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
+ * Copyright (c)2003,2004 by Peter Busser <peter@adamantix.org>
  * This file has been released under the GNU Public Licence version 2 or later
  */
 
@@ -21,6 +21,12 @@ void doit( void )
 {
 	char buf[4];
 
-	strcpy( buf, (const char *)overflow );
+	if (strlen((const char *)overflow) > 4) {
+		strcpy( buf, (const char *)overflow );
+	} else {
+		fprintf( stderr, "paxtest: bad luck, try different "
+			"compiler options.\n" );
+		exit(1);
+	}
 }
 
